#
#  (C) Tenable Network Security, Inc.
#


  desc = "
Synopsis :

The remote Windows host has a program that may be affected by
multiple vulnerabilities. 

Description :

The remote host is running a version of OpenOffice.org which is older
than version 2.2.  Those versions are reportedly affected by a stack
buffer overflow vulnerability in its handling of StarCalc documents. 
If a remote attacker can trick a user into opening a specially-crafted
StarCalc document, he can execute arbitrary code on the remote host
subject to the user's privileges. 

In addition, versions 2.0 - 2.1 reportedly have a heap buffer overflow
vulnerability that can be triggered when importing a specially-crafted
WordPerfect document, resulting in arbitrary code execution.

See also :

http://archives.neohapsis.com/archives/bugtraq/2007-04/0089.html
http://www.openoffice.org/security/CVE-2007-2.html
http://www.openoffice.org/security/CVE-2007-0238

Solution :

Upgrade to OpenOffice version 2.2 or later. 

Risk factor : 

High / CVSS Base Score : 8.0
(AV:R/AC:H/Au:NR/C:C/I:C/A:C/B:N)";


if (description)
{
  script_id(25004);
  script_version("$Revision: 1.3 $");
  script_cve_id("CVE-2007-0002", "CVE-2007-0238", "CVE-2007-1466");
  script_bugtraq_id(23006, 23067);

  script_name(english:"OpenOffice < 2.2 Multiple Vulnerabilities");
  script_summary(english:"Checks version of OpenOffice"); 
 
  script_description(english:desc);
 
  script_category(ACT_GATHER_INFO);
  script_family(english:"Windows");

  script_copyright(english:"This script is Copyright (C) 2007 Tenable Network Security, Inc.");

  script_dependencies("smb_hotfixes.nasl");
  script_require_keys("SMB/Registry/Enumerated");
  script_require_ports(139, 445);

  exit(0);
}


include("global_settings.inc");
include("smb_func.inc");


# Connect to the appropriate share.
if (!get_kb_item("SMB/Registry/Enumerated")) exit(0);
name    =  kb_smb_name();
port    =  kb_smb_transport();
if (!get_port_state(port)) exit(0);
login   =  kb_smb_login();
pass    =  kb_smb_password();
domain  =  kb_smb_domain();

soc = open_sock_tcp(port);
if (!soc) exit(0);

session_init(socket:soc, hostname:name);
rc = NetUseAdd(login:login, password:pass, domain:domain, share:"IPC$");
if (rc != 1)
{
  NetUseDel();
  exit(0);
}


# Connect to remote registry.
hklm = RegConnectRegistry(hkey:HKEY_LOCAL_MACHINE);
if (isnull(hklm))
{
  NetUseDel();
  exit(0);
}


# Check whether it's installed.
path = NULL;

key = "SOFTWARE\Microsoft\Windows\CurrentVersion\App Paths\soffice.exe";
key_h = RegOpenKey(handle:hklm, key:key, mode:MAXIMUM_ALLOWED);
if (!isnull(key_h))
{
  item = RegQueryValue(handle:key_h, item:"Path");
  if (!isnull(item)) 
  {
    path = item[1];
     path = ereg_replace(pattern:"^(.+)\\$", replace:"\1", string:path);
  }

  RegCloseKey(handle:key_h);
}
RegCloseKey(handle:hklm);
if (isnull(path))
{
  NetUseDel();
  exit(0);
}


# Determine the version of the file.
share = ereg_replace(pattern:"^([A-Za-z]):.*", replace:"\1$", string:path);
cfg =  ereg_replace(pattern:"^[A-Za-z]:(.*)", replace:"\1\program\version.ini", string:path);
NetUseDel(close:FALSE);

rc = NetUseAdd(login:login, password:pass, domain:domain, share:share);
if (rc != 1)
{
  NetUseDel();
  exit(0);
}

fh = CreateFile(
  file:cfg,
  desired_access:GENERIC_READ,
  file_attributes:FILE_ATTRIBUTE_NORMAL,
  share_mode:FILE_SHARE_READ,
  create_disposition:OPEN_EXISTING
);
if (!isnull(fh))
{
  # nb: limit how much we'll read.
  fsize = GetFileSize(handle:fh);
  if (fsize > 1000) fsize = 1000;

  ver = NULL;
  chunk = 1024;
  ofs = 0 ;

  while (fsize > 0 && ofs <= fsize)
  {
    data = ReadFile(handle:fh, length:chunk, offset:ofs);
    if (strlen(data) == 0) break;
    data = str_replace(find:raw_string(0), replace:"", string:data);
    if ("MsiProductVersion" >< data)
      ver = ereg_replace(pattern:"^.+MsiProductVersion *= *([0-9.]+).*$", replace:"\1", string:data);
    if (isnull(ver)) ofs += chunk;
    else break;
  }
  CloseFile(handle:fh);

  if (!isnull(ver) && ver =~ "^([0-1]\.|2\.[01]([^0-9]|$))")
  {
    report = string(
      desc,
      "\n\n",
      "Plugin output :\n",
      "\n",
      "OpenOffice version ", ver, " is installed under :\n",
      "\n",
      "  ", path
    );
    security_hole(port:port, data:report);
  }
}


# Clean up.
NetUseDel();
